@@ -1,5 +1,10 @@
 import sys
 import rich
+# from helper import Helper
+# from content import Content
+# from reading import Reading
+# from contributing import Contributing
+# from custom_argparse import ArgumentParser
 from .helper import Helper
 from .content import Content
 from .reading import Reading
@@ -7,25 +12,13 @@ from .contributing import Contributing
 from .custom_argparse import ArgumentParser
 
 
-def list_Wikis_Codes():
-    wikis = Helper.get_Wikis_Codes()
-    print(f"## List of `{len(wikis)}` Wikipedias and its languages codes:\n")
-    for code, wiki in wikis.items():
-        print(f"{wiki}:`{code}`", end=', ')
-    print('\n') ; exit()
-
-
 def main():
 
-    rich.print('''
-            [dodger_blue2]▌│║▌║▌█║▌║║▌│║▌│║▌║▌█║[/][spring_green4]▌█║▌║│▌║│▌║│█║│▌[/][dodger_blue2]║▌│█║▌│▌║│▌║║▌║▌█║▌║│▌[/]
-            [dodger_blue2]▌│║▌║▌█║▌║║▌│║▌│║▌║▌█║[/][red]WIKISTATS-TO-CSV[/][dodger_blue2]║▌│█║▌│▌║│▌║║▌║▌█║▌║│▌[/]
-            [dodger_blue2]▌│║▌║▌█║▌║║▌│║▌│║▌║▌█║[/][spring_green4]▌█║▌║│▌║│▌║│█║│▌[/][dodger_blue2]║▌│█║▌│▌║│▌║║▌║▌█║▌║│▌[/]
-            ''')
+    Helper.logo_msg()
 
     try:
         if sys.argv[1]=='-lw' or sys.argv[1]=='--list-wikis':
-            list_Wikis_Codes()
+            Helper.list_Wikis_Codes()
     except IndexError:
         pass
 
@@ -38,10 +31,10 @@ def main():
     parser.add_argument('-f', '--filter', type=str, required=False, default='no-filter', metavar='', help='Metrics Filters')
     parser.add_argument('-i', '--interval', type=str, required=False, default='monthly', metavar='', help='Time Intervals')
     parser.add_argument('-lw', '--list-wikis', type=str, required=False, metavar='', help='List Wikipedias')
-    
+
     try:
         args = parser.parse_args()
-    
+
         if args.wiki!=None:
 
             if args.metric=='content':
@@ -149,7 +142,7 @@ def main():
 
                 else:
                     print(f"\u001b[91mError:\u001b[0m wikistats2csv metric `contributing` does not support this query: '{args.query}'.\n")
-            
+
             else:
                 print(f"\u001b[91mError:\u001b[0m wikistats2csv does not support this metric: '{args.metric}'.\n")
 
@@ -158,4 +151,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
